# Sample Card

**Due:** 2019-05-07

Sample description

## Checklist

- [x] Completed item
- [ ] Incomplete item

## Attachments

- [Example link](https://example.com)

## Comment from Brian Rutledge on 2019-05-06

Sample comment
